@@ -1,4 +1,7 @@
 test_that("print", {
+  if (!requireNamespace("distr6", quietly = TRUE)) {
+    skip("distr6 not installed.")
+  }
   fit <- akritas(Surv(time, status) ~ ., data = rats[1:10, ])
   expect_output(print(fit), "akritas(formula = Surv(time, status) ~ ., data = rats[1:10, ])",
                 fixed = TRUE)
